@@ -4,30 +4,15 @@ import config from 'config';
 import { QueryTypes, type Sequelize } from 'sequelize';
 import type { Logger } from 'winston';
 import { selectFacilityIds } from '@tamanu/utils/selectFacilityIds';
-import { NON_LOGGED_TABLES, NON_SYNCING_TABLES } from './constants';
+import { GLOBAL_EXCLUDE_TABLES, NON_LOGGED_TABLES, NON_SYNCING_TABLES } from './constants';
 import { SYNC_TICK_FLAGS } from '../../sync/constants';
 
-const tableNameMatch = (schema: string, table: string, matches: string[]) => {
-  const matchTableSchemas = matches
-    .map(match => match.split('.'))
-    .map(([excludeSchema, excludeTable]) => ({ schema: excludeSchema, table: excludeTable }));
-  const wholeSchemaMatches = matchTableSchemas
-    .filter(({ table: matchTable }) => matchTable === '*')
-    .map(({ schema: matchSchema }) => matchSchema);
-  if (wholeSchemaMatches.includes(schema)) {
-    return true;
-  }
-
-  return matchTableSchemas.some(
-    ({ schema: matchSchema, table: matchTable }) => schema === matchSchema && table === matchTable,
-  );
-};
-
 export const tablesWithoutColumn = (
   sequelize: Sequelize,
   column: string,
   excludes: string[] = NON_SYNCING_TABLES,
 ) => {
+  const allExcludes = [...GLOBAL_EXCLUDE_TABLES, ...excludes];
   return sequelize
     .query(
       `
@@ -42,10 +27,9 @@ export const tablesWithoutColumn = (
       AND pg_attribute.attname = $column
     WHERE pg_namespace.nspname IN ('public', 'logs')
       AND pg_class.relkind = 'r'
-      AND pg_attribute.attname IS NULL
-      AND (pg_namespace.nspname || '.' || pg_class.relname) NOT IN ($excludes);
+      AND pg_attribute.attname IS NULL;
   `,
-      { type: QueryTypes.SELECT, bind: { column, excludes: NON_SYNCING_TABLES } },
+      { type: QueryTypes.SELECT, bind: { column } },
     )
     .then(rows =>
       rows
@@ -53,25 +37,25 @@ export const tablesWithoutColumn = (
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !tableNameMatch(schema, table, excludes)),
+        .filter(({ schema, table }) => !allExcludes.includes(`${schema}.${table}`)),
     );
 };
-
-const tablesWithoutTrigger = (
+export const tablesWithoutTrigger = (
   sequelize: Sequelize,
   prefix: string,
   suffix: string,
   excludes: string[] = NON_SYNCING_TABLES,
-) =>
-  sequelize
+) => {
+  const allExcludes = [...GLOBAL_EXCLUDE_TABLES, ...excludes];
+  return sequelize
     .query(
       `
       SELECT
         t.table_schema as schema,
         t.table_name as table
       FROM information_schema.tables t
-      LEFT JOIN information_schema.triggers triggers ON 
-        t.table_name = triggers.event_object_table 
+      LEFT JOIN information_schema.triggers triggers ON
+        t.table_name = triggers.event_object_table
         AND t.table_schema = triggers.event_object_schema
         AND triggers.trigger_name = substring(concat($prefix::text, lower(t.table_name), $suffix::text), 0, 64)
       WHERE
@@ -88,24 +72,26 @@ const tablesWithoutTrigger = (
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !tableNameMatch(schema, table, excludes)),
+        .filter(({ schema, table }) => !allExcludes.includes(`${schema}.${table}`)),
     );
+};
 
-const tablesWithTrigger = (
+export const tablesWithTrigger = (
   sequelize: Sequelize,
   prefix: string,
   suffix: string,
   excludes: string[] = NON_SYNCING_TABLES,
-) =>
-  sequelize
+) => {
+  const allExcludes = [...GLOBAL_EXCLUDE_TABLES, ...excludes];
+  return sequelize
     .query(
       `
       SELECT
         t.table_schema as schema,
         t.table_name as table
       FROM information_schema.tables t
-      JOIN information_schema.triggers triggers ON 
-        t.table_name = triggers.event_object_table 
+      JOIN information_schema.triggers triggers ON
+        t.table_name = triggers.event_object_table
         AND t.table_schema = triggers.event_object_schema
         AND triggers.trigger_name = substring(concat($prefix::text, lower(t.table_name), $suffix::text), 0, 64)
       WHERE
@@ -121,8 +107,9 @@ const tablesWithTrigger = (
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !excludes.includes(`${schema}.${table}`)),
+        .filter(({ schema, table }) => !allExcludes.includes(`${schema}.${table}`)),
     );
+};
 
 export async function runPreMigration(log: Logger, sequelize: Sequelize) {
   // remove sync tick trigger before migrations
